@@ -159,20 +159,18 @@ class Object():
         if "endpoint" in dir(self.__class__):
             self.endpoint=getattr(self.__class__, 'endpoint').format(guid=self.guid)
 
-    def update(self, data=None):
+    def update(self, **data):
         """
         Updates the object properties in Arena based on attributes passed in.
 
         Required arguments:
 
-        - data - A dictionary of object properties to update
+        - **data - Object properties to update. Use attribute GUIDs to update custom attributes.
         """
 
-        data=data or self.__dict__
+        response = self._client._put(self.endpoint, data)
 
-        data= self._client._put(self.endpoint, data)
-
-        self.__dict__.update(data)
+        self.__dict__.update(response)
 
     def delete(self):
         """
@@ -188,12 +186,6 @@ class Object():
         data = self._client._get(self.endpoint)
         self.__dict__.update(data)
 
-    def open(self):
-        """
-        Open the object in the browser. Requires also being logged into Arena in the default web browser.
-        """
-        webbrowser.open(f"{self._client.browser_url}{self.guid}")
-
     @property
     def cache_key(self):
         return f"{self.__class__.__name__};{self.guid}"
@@ -203,3 +195,12 @@ class Object():
     def user(self):
         return self._client.User(self.creator['guid'])
     
+class openable_mixin():
+
+
+    def open(self):
+        """
+        Open the object in the browser. Requires also being logged into Arena in the default web browser.
+        """
+
+        webbrowser.open(f"{self._client.browser_url}{self.guid}")
\ No newline at end of file
